@@ -324,16 +324,16 @@ Con *create_workspace_on_output(Output *output, Con *content) {
 
 /*
  * Returns true if the workspace is currently visible. Especially important for
- * multi-monitor environments, as they can have multiple currenlty active
+ * multi-monitor environments, as they can have multiple currently active
  * workspaces.
  *
  */
 bool workspace_is_visible(Con *ws) {
     Con *output = con_get_output(ws);
-    if (output == NULL)
+    if (output == NULL) {
         return false;
+    }
     Con *fs = con_get_fullscreen_con(output, CF_OUTPUT);
-    LOG("workspace visible? fs = %p, ws = %p\n", fs, ws);
     return (fs == ws);
 }
 
